==> gm4_auto_crafting_1_20.zip: README.md <==
# <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="GM4 Logo" width="32" /> Auto Crafting by Gamemode 4 

Excited for the new 1.21 crafter block? Want to start making the cake factory of your dreams right now? Try out Gamemode 4's take on auto-crafting, available right now for 1.19 and 1.20!

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_auto_crafting/images/auto_crafter.webp" alt="Auto Crafter at work" width="350"/>   

### Features
- Crafts any vanilla item.
- Set the recipe shape, give it ingredients one at a time, and power the piston to craft the item
- Build a cool steampunk multiblock structure

### Creation
Craft the auto-crafter in a [Custom Crafter](https://wiki.gm4.co/wiki/Custom_Crafters)

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_auto_crafting/images/crafting_recipe.png" alt="Auto Crafter Recipe" width="150"/> 

Build the Multiblock Structure

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_auto_crafting/images/setting-up-a-crafter.webp" alt="Auto Crafter Recipe" width="200"/> 

### Usage
- Set the shape of your recipe inside the Auto Crafter, using any items
- Fill the top barrel with the ingredients of your recipe, in order
- Power the Piston to craft the item
- Retrieve the result from the bottom barrel

### More Info
[<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_wiki_logo.png" alt="Gamemode 4 Wiki Logo" width="40" align="center"/> **Read the Wiki**](https://wiki.gm4.co/wiki/Custom_Crafters/Auto_Crafting)

### Credits
- Creator: [BluePsychoRanger](https://twitter.com/BluPsychoRanger)
- Icon Design: Hozz
- Textures: [Kyrius](http://discordapp.com/users/287287322360414218)

---
## About Gamemode 4 <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="Gamemode 4 Logo" width="20"/>
Gamemode 4 is a series of command-powered creations that are designed to change and enhance the survival experience. All of our modules are designed to work together flawlessly, and are balanced for usage in a survival setting. Pick and choose your favorites from our [website](https://gm4.co), or wherever you get datapacks.

==> gm4_auto_crafting_1_21.zip: README.md <==
# <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="GM4 Logo" width="32" /> Auto Crafting by Gamemode 4

Try out Gamemode 4's take on auto-crafting!

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_auto_crafting/images/auto_crafter.webp" alt="Auto Crafter at work" width="350"/>   

### Features
- Crafts any vanilla item.
- Set the recipe shape, give it ingredients one at a time, and power the piston to craft the item
- Build a cool steampunk multiblock structure

### Creation
Craft the auto-crafter in a [Custom Crafter](https://wiki.gm4.co/wiki/Custom_Crafters)

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_auto_crafting/images/crafting_recipe.png" alt="Auto Crafter Recipe" width="150"/> 

Build the Multiblock Structure

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_auto_crafting/images/setting-up-a-crafter.webp" alt="Auto Crafter Recipe" width="200"/> 

### Usage
- Set the shape of your recipe inside the Auto Crafter, using any items
- Fill the top barrel with the ingredients of your recipe, in order
- Power the Piston to craft the item
- Retrieve the result from the bottom barrel

### More Info
[<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_wiki_logo.png" alt="Gamemode 4 Wiki Logo" width="40" align="center"/> **Read the Wiki**](https://wiki.gm4.co/wiki/Custom_Crafters/Auto_Crafting)

### Credits
- Creator: [BPR](https://bsky.app/profile/bpr02.com)
- Icon Design: Hozz
- Textures: [Kyrius](https://bsky.app/profile/kyriuspixels.bsky.social)

---
## About Gamemode 4 <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="Gamemode 4 Logo" width="20"/>
Gamemode 4 is a series of command-powered creations that are designed to change and enhance the survival experience. All of our modules are designed to work together flawlessly, and are balanced for usage in a survival setting. Pick and choose your favorites from our [website](https://gm4.co), or wherever you get datapacks.
